@@ -30,6 +30,7 @@ def lineplot(
     independent_y: bool = False,
     spacing: int = 5,
     color: Optional[Union[str, alt.Color]] = None,
+    shape: Optional[Union[str, alt.Shape]] = None,
     height: Optional[int] = None,
     width: Optional[int] = None,
 ) -> Chart:
@@ -59,6 +60,7 @@ def lineplot(
         independent_y: Whether y-axes are independent
         spacing: Spacing between facets
         color: Colorscale
+        shape: Shape encoding
         height: Height of plot in facet
         width: Width of plot in facet
 
@@ -70,6 +72,11 @@ def lineplot(
     else:
         color_kwarg = {"color": color}
 
+    if shape is None:
+        shape_kwarg = {}
+    else:
+        shape_kwarg = {"shape": shape}
+
     if limits is not None:
         y_scale = alt.Scale(zero=False, domain=limits)
     else:
@@ -91,7 +98,8 @@ def lineplot(
         .encode(
             x=alt.X(x, title=""),
             y=alt.Y(y, scale=y_scale, aggregate=aggregate),
-            **color_kwarg
+            **color_kwarg,
+            **shape_kwarg
         )
     )
 
@@ -99,7 +107,10 @@ def lineplot(
         alt.Chart()
         .mark_errorbar(extent=error_extent)
         .encode(
-            x=alt.X(x, title=""), y=alt.Y(y, scale=y_scale), **color_kwarg
+            x=alt.X(x, title=""),
+            y=alt.Y(y, scale=y_scale),
+            **color_kwarg,
+            **shape_kwarg
         )
     )
 
@@ -140,11 +151,11 @@ def lineplot(
         chart = chart.facet(**facet_kwargs)
 
     if independent_x:
-        chart = chart.resolve_scale(x='independent')
+        chart = chart.resolve_scale(x="independent")
 
     if independent_y:
-        chart = chart.resolve_scale(y='independent')
+        chart = chart.resolve_scale(y="independent")
 
     chart = chart.configure_header(titleOrient=title_orient, labelOrient=label_orient)
-    
+
     return chart
